"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var core_1 = require("../utils/core");
var strings_1 = require("../utils/strings");
var svg_1 = require("../utils/svg");
function render(svgFile, options) {
    var contextInterface = svg_1.generateTSInterface(svgFile.contextInterface);
    if (contextInterface) {
        delete svgFile.contextInterface;
    }
    // prettier-ignore
    var interfaceOutput = contextInterface
        ? "export interface " + strings_1.pascalCase(svgFile.name) + "Context " + contextInterface + ";"
        : '';
    // prettier-ignore
    return interfaceOutput + "export const " + strings_1.pascalCase(svgFile.name) + " = " + core_1.printObj(svgFile) + ";";
}
exports.render = render;
function saveFile(options, blueprint) {
    return function (svgFile) {
        var filePath = options.output + path.sep + svgFile.name + '.ts';
        delete svgFile.path;
        svgFile.svg = svg_1.compactSVG(svgFile.svg);
        core_1.mkdirRecursiveSync(path.dirname(filePath));
        fs.writeFileSync(filePath, render(svgFile, options));
    };
}
exports.saveFile = saveFile;
function generateIndexFile(options, files) {
    var filePath = options.output + path.sep + 'index.ts';
    var indexFileContents = files
        .map(function (file) {
        var svgObjectName = strings_1.pascalCase(file.name);
        var context = file.contextDefaults ? ", " + svgObjectName + "Context" : '';
        return "export { " + svgObjectName + context + " } from './" + file.name + "';";
    })
        .join('\n');
    core_1.mkdirRecursiveSync(options.output + path.sep);
    fs.writeFileSync(filePath, indexFileContents);
}
exports.generateIndexFile = generateIndexFile;
