"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CommandLineTools = /** @class */ (function () {
    function CommandLineTools(packageName, args, options) {
        this.packageName = packageName;
        this.options = options;
        Object.assign(this.options.aliases, this.options.aliases, CommandLineTools.kvvk(this.options.aliases));
        this.arguments = CommandLineTools.parseArguments(args);
        this.args = new Proxy(this.arguments, {
            get: function (target, name) {
                return name in target ? target[name] : target[options.aliases[name]] || null;
            }
        });
    }
    CommandLineTools.prototype.help = function () {
        var _this = this;
        if (this.options.banner) {
            this.options.banner.forEach(function (_) { return console.log(_); });
        }
        if (this.options.version) {
            console.log('Version: ' + this.options.version);
        }
        console.log('');
        console.log('\x1b[35m' + this.packageName + ' Usage:\x1b[0m');
        console.log('');
        var keyPad = 0;
        Object.keys(this.options.help).forEach(function (key) {
            var _a = _this.options.help[key].split('|'), description = _a[0], exampleValue = _a[1];
            if (key.length + 5 + exampleValue.length > keyPad)
                keyPad = key.length + 5 + exampleValue.length;
        });
        keyPad += 2;
        Object.keys(this.options.help).forEach(function (key) {
            var _a = _this.options.help[key].split('|'), description = _a[0], exampleValue = _a[1];
            var outputKeyExample = '  --' + key + ' ' + exampleValue;
            var paddedKey = padEnd(outputKeyExample, keyPad, '');
            var colorDescription = ['\x1b[35m', description, '\x1b[0m'].join('');
            console.log(paddedKey + colorDescription);
        });
        console.log('');
        return false;
    };
    CommandLineTools.parseArguments = function (arr) {
        return arr.reduce(function (prevValue, valorActual, index, vector) {
            var isKey = vector[index].indexOf('-') === 0;
            if (isKey) {
                var next = arr[index + 1];
                var nextIsValue = next && next.indexOf('-') !== 0;
                prevValue[vector[index].replace(/-/gi, '')] = nextIsValue ? next : true;
            }
            return prevValue;
        }, {});
    };
    CommandLineTools.kvvk = function (obj) {
        return Object.keys(obj).reduce(function (a, b, c, d) {
            a[obj[b]] = b;
            return a;
        }, {});
    };
    return CommandLineTools;
}());
exports.CommandLineTools = CommandLineTools;
function padEnd(str, targetLength, padString) {
    targetLength = targetLength >> 0; //floor if number or convert non-number to 0;
    padString = String(padString || ' ');
    if (str.length > targetLength) {
        return String(str);
    }
    else {
        targetLength = targetLength - str.length;
        if (targetLength > padString.length) {
            padString += padString.repeat(targetLength / padString.length); //append to original to ensure we are longer than needed
        }
        return String(str) + padString.slice(0, targetLength);
    }
}
