"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var regexp_1 = require("./regexp");
var svg_1 = require("./svg");
function loadSvgFile(options) {
    return function (fileName) {
        var svg = fs.readFileSync(fileName, 'utf8').replace(regexp_1.lineBreaksRegExp, '');
        return {
            path: fileName,
            name: path.basename(fileName).replace('.svg', ''),
            svg: svg_1.removeStyles(svg),
            css: svg_1.extractStyles(svg, options)
        };
    };
}
exports.loadSvgFile = loadSvgFile;
function printObj(obj, tab) {
    if (tab === void 0) { tab = ''; }
    var isArray = Array.isArray(obj);
    var str = isArray ? tab + '[' : tab + '{';
    for (var prop in obj) {
        if (obj.hasOwnProperty(prop)) {
            var val1 = obj[prop];
            var val2 = '';
            var type = Object.prototype.toString.call(val1);
            switch (type) {
                case '[object Array]':
                case '[object Object]':
                    val2 = printObj(val1);
                    break;
                case '[object String]':
                    val2 = "'" + val1 + "'";
                    break;
                default:
                    val2 = val1;
            }
            str += tab + prop + ': ' + val2 + ',';
        }
    }
    // remove extra comma for last property
    str = str.substring(0, str.length - 1);
    return isArray ? str + ']' : str + '}';
}
exports.printObj = printObj;
function walkSync(dir, filelist) {
    if (filelist === void 0) { filelist = []; }
    if (dir[dir.length - 1] !== '/') {
        dir = dir.concat('/');
    }
    var files = fs.readdirSync(dir);
    files.forEach(function (file) {
        if (fs.statSync(dir + file).isDirectory()) {
            filelist = walkSync(dir + file + '/', filelist);
        }
        else {
            filelist.push(dir + file);
        }
    });
    return filelist;
}
exports.walkSync = walkSync;
function mkdirRecursiveSync(directory) {
    var path = directory.replace(/\/$/, '').split('/');
    for (var i = 1; i <= path.length; i++) {
        var segment = path.slice(0, i).join('/');
        !fs.existsSync(segment) ? fs.mkdirSync(segment) : null;
    }
}
exports.mkdirRecursiveSync = mkdirRecursiveSync;
function dotObject(path, obj, value) {
    if (obj === void 0) { obj = {}; }
    if (value === void 0) { value = null; }
    var result = path
        .split('.')
        .slice(1)
        .reduce(function (parent, key, index, arr) {
        parent[key] =
            index === arr.length - 1
                ? typeof value === 'object'
                    ? Object.assign(parent[key], value)
                    : value
                : parent[key] || {};
        return parent[key];
    }, obj);
    return value ? obj : result;
}
exports.dotObject = dotObject;
function tsc(template, context) {
    var keys = Object.keys(context), replacer = /@{[\s]?([\s\S]*)[\s]?}/;
    while (replacer.test(template)) {
        template = template.replace(replacer, '${$1}');
    }
    var fnTemplate = 'const {' + keys + '}=context; return`' + template + '`';
    return new Function('context', fnTemplate);
}
exports.tsc = tsc;
