"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var postcss = require("postcss");
var prefixer = require("postcss-prefix-selector");
var regexp_1 = require("./regexp");
var strings_1 = require("./strings");
function isSVG(buffer) {
    return regexp_1.svgIsSVG.test(buffer);
}
exports.isSVG = isSVG;
function parseViewbox(viewBox) {
    var _a = viewBox.split(' ').map(function (_) {
        return parseInt(_, 10);
    }), minx = _a[0], miny = _a[1], width = _a[2], height = _a[3];
    return { minx: minx, miny: miny, width: width, height: height };
}
exports.parseViewbox = parseViewbox;
function parseAttributes(root) {
    var width = root.match(regexp_1.svgWidthRegExp);
    var height = root.match(regexp_1.svgHeightRegExp);
    var viewBox = root.match(regexp_1.svgViewBoxRegExp);
    return __assign({}, (width ? { width: width[2] } : {}), (height ? { height: height[2] } : {}), (viewBox ? { viewBox: parseViewbox(viewBox[2]) } : {}));
}
exports.parseAttributes = parseAttributes;
function getMetadata(svgFile) {
    var buffer = svgFile.svg;
    var root = buffer.match(regexp_1.svgRootRegExp);
    if (root) {
        var attrs = parseAttributes(root[0]);
        if (attrs.width && attrs.height) {
            return getDimensions(attrs);
        }
        if (attrs.viewBox) {
            return getViewBoxDimensions(attrs);
        }
    }
    console.log("[svg2ts] \u001B[31mUnable to determine dimensions of: \u001B[33m" + svgFile.path + "\u001B[0m");
    return {};
}
exports.getMetadata = getMetadata;
function getDimensions(attrs) {
    var width = attrs.width, height = attrs.height;
    return __assign({ width: width,
        height: height }, (attrs.viewBox ? { viewBox: attrs.viewBox } : {}));
}
exports.getDimensions = getDimensions;
function getViewBoxDimensions(attrs) {
    var ratio = attrs.viewBox.width / attrs.viewBox.height;
    if (attrs.width) {
        return __assign({ width: attrs.width, height: Math.floor(attrs.width / ratio) }, (attrs.viewBox ? { viewBox: attrs.viewBox } : {}));
    }
    if (attrs.height) {
        return __assign({ width: Math.floor(attrs.height * ratio), height: attrs.height }, (attrs.viewBox ? { viewBox: attrs.viewBox } : {}));
    }
    return { width: '100%', height: '100%', viewBox: { width: attrs.viewBox.width, height: attrs.viewBox.height } };
}
exports.getViewBoxDimensions = getViewBoxDimensions;
function getInlineStyles(svg) {
    var matches = svg.match(regexp_1.styleExtractRegExp);
    return matches ? matches.join('').replace(regexp_1.styleTagRegExp, '') : '';
}
exports.getInlineStyles = getInlineStyles;
function compactCSS(css) {
    // https://codepen.io/arlinadesign/pen/KVNBKK
    var c = /@(media|-w|-m|-o|keyframes|page)(.*?)\{([\s\S]+?)?\}\}/gi, t = css.length;
    css = css
        .replace(/(\n+)?(\/\*[\w\W]*?\*\/)(\n+)?/gm, '\n$2\n')
        .replace(/([\n\r\t\s ]+)?([\,\:\;\{\}]+?)([\n\r\t\s ]+)?/g, '$2')
        .replace(/\}(?!\})/g, '}\n')
        .replace(c, function (e) {
        return e.replace(/\n+/g, '');
    })
        .replace(/;\}/g, '}')
        .replace(/\:0(px|em|pt)/gi, ':0')
        .replace(/ 0(px|em|pt)/gi, ' 0')
        .replace(/\s+\!important/gi, '!important')
        .replace(/(^\n+|\n+$)/, '')
        .replace(/\t/g, '')
        .replace(/\n/g, '');
    return css;
}
exports.compactCSS = compactCSS;
function compactSVG(source) {
    source = source
        .replace(/<svg.[^>]*>/g, '')
        .replace(/<\/svg>/gi, '')
        .replace(/\<\!--\s*?[^\s?\[][\s\S]*?--\>/g, '')
        .replace(/\>\s*\</g, '><');
    source = source.replace(/<([^>]+)>/g, function (str, tagInner) {
        tagInner = tagInner
            .replace(/^ +| +$/g, '') // Not .trim() that removes \f.
            .replace(/(?: *\/ +| +\/ *)/g, '/') // Remove whitespaces in </ p> or <br />
            .replace(/ *= */g, '=')
            .replace(/( +)/g, ' ');
        return '<' + tagInner + '>';
    });
    return source.trim();
}
exports.compactSVG = compactSVG;
function removeDefaultTemplateValues(source) {
    return source.replace(regexp_1.propertyValueKeyRegExp, '{{$2}}');
}
exports.removeDefaultTemplateValues = removeDefaultTemplateValues;
function extractStyles(svg, options) {
    var cssmin = compactCSS(getInlineStyles(svg)
        .replace(regexp_1.singleQuoteRegExp, "\\'")
        .replace(regexp_1.svgAttributeRegExp, " [attr.$1]=\"context.$2\""))
        .replace(regexp_1.propertyBeginRegExp, '_oo_')
        .replace(regexp_1.propertyEndRegExp, '_OO_');
    return postcss()
        .use(prefixer({
        prefix: "." + strings_1.kebabCase(options.module) + "-_oo_0|uuid_OO_"
    }))
        .process(cssmin)
        .css.replace(regexp_1.propertyBeginToggleRegExp, '{{')
        .replace(regexp_1.propertyEndToggleRegExp, '}}');
}
exports.extractStyles = extractStyles;
function removeStyles(svg) {
    return svg.replace(regexp_1.svgStyleRegExp, '');
}
exports.removeStyles = removeStyles;
function removeScripts(svg) {
    return svg.replace(regexp_1.svgScriptRegExp, '');
}
exports.removeScripts = removeScripts;
function generateTSInterface(obj) {
    return obj && obj.toString().replace(regexp_1.colonRegExp, '?:');
}
exports.generateTSInterface = generateTSInterface;
function filterSvg(file) {
    return file.includes('svg') && path.extname(file) === '.svg';
}
exports.filterSvg = filterSvg;
function filterSvgContent(svgFilePath) {
    return isSVG(svgFilePath.svg);
}
exports.filterSvgContent = filterSvgContent;
function filterKnownDimensions(fileObj) {
    var _a = getMetadata(fileObj), width = _a.width, height = _a.height, viewBox = _a.viewBox;
    return (width && height) || (viewBox && viewBox.width && viewBox.height);
}
exports.filterKnownDimensions = filterKnownDimensions;
