"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("../utils/core");
exports.angularDynamicClassTemplate = core_1.tsc("\nimport {\n  ChangeDetectionStrategy,\n  ChangeDetectorRef,\n  Component,\n  Input,\n  OnInit\n} from '@angular/core';\n\nimport {\n  @{className},\n  @{className}Context,\n  getSVGViewBox\n} from '../assets';\n\n@Component({\n  selector: '@{selector}',\n  template: @{className}.svg,\n  changeDetection: ChangeDetectionStrategy.OnPush\n})\nexport class @{className}Component implements OnInit {\n  public static UUID = 0;\n  public baseUrl: string;\n  @Input() public height: number | string = @{className}.height;\n  @Input() public viewBox: string = getSVGViewBox(@{className}.viewBox);\n  @Input() public width: number | string = @{className}.width;\n  @Input()\n  public set context(ctx: @{className}Context) {\n    this.updateContext(ctx);\n  }\n  public get context() {\n    return this._context;\n  }\n\n  private _context: @{className}Context = @{className}.contextDefaults;\n\n  constructor(private _ref: ChangeDetectorRef) {}\n\n  public getURLBase(value) {\n    return \\`url('\\${this.baseUrl}#\\${value}-\\${this.context.uuid}')\\`;\n  }\n\n  public getXlinkBase(value) {\n    return \\`\\${ this.baseUrl }#\\${ value }-\\${this.context.uuid}\\`;\n  }\n\n  public ngOnInit() {\n    this.baseUrl = window.location.href.replace(window.location.hash, '');\n    this.context.uuid = @{className}Component.UUID++;\n  }\n\n  public updateContext(ctx: any) {\n    this._context = Object.assign(\n      {},\n      this._context ? this._context : @{className}.contextDefaults,\n      ctx\n    );\n    this._ref.markForCheck();\n  }\n}\n", { className: '', selector: '' });
exports.angularDynamicModuleTemplate = core_1.tsc("\nimport { NgModule } from '@angular/core';\nimport { CommonModule } from '@angular/common';\nimport {\n  @{\n    components.map((component)=>{\n      return `@{component}Component`;\n  }).join(',\\n  ')\n  }\n} from './components'\n\nconst comps = [\n  @{\n    components.map((component)=>{\n        return `@{component}Component`;\n    }).join(',\\n  ')\n  }\n];\n\n@NgModule({\n  declarations: [ ...comps ],\n  exports: [ ...comps ],\n  imports:[ CommonModule ],\n  entryComponents: [ ...comps ]\n})\nexport class @{moduleName}Module { }\n", {
    moduleName: '',
    components: []
});
exports.svgIconClassTemplate = core_1.tsc("\nexport interface SVG2TSDimensions {\n  height?: number | undefined;\n  minx?: number | undefined;\n  miny?: number | undefined;\n  width?: number | undefined;\n}\n\nexport interface SVG2TSFile {\n  contextDefaults?: { [key: string]: string | number } | undefined;\n  css?: string;\n  height?: string | undefined;\n  name: string;\n  svg: string;\n  viewBox?: SVG2TSDimensions | undefined;\n  width?: string | undefined;\n}\n\nimport {\n  AfterViewInit,\n  ChangeDetectionStrategy,\n  ChangeDetectorRef,\n  Component,\n  ComponentFactoryResolver,\n  ElementRef,\n  Input,\n  OnInit,\n  ViewChild,\n  ViewContainerRef,\n} from '@angular/core';\n\nimport {\n  @{assets.join(',\\n  ')}\n} from '../assets';\n\n@{\n    components.map((component)=>{\n        return `import { ${component.component}Component } from './${component.name}.component';`;\n    }).join('\\n')\n}\n\nconst assetsMap = {\n@{\n    assets.map((asset)=>{\n        return `[${asset}.name]: ${asset}`;\n    }).join(',\\n  ')\n}\n};\n\nconst componentsMap = {\n@{\n    components.map((component)=>{\n        return `[${component.component}.name]: ${component.component}Component`;\n    }).join(',\\n  ')\n}\n};\n\n\n@Component({\n  selector: '@{selector}',\n  template: \\`\n  <ng-container *ngIf=\"!iconFile.contextDefaults\">\n    <svg\n      [attr.width]=\"width\"\n      [attr.height]=\"height\"\n      [attr.viewBox]=\"getViewBox()\"\n      >\n    </svg>\n  </ng-container>\n  <ng-template #dynSvg></ng-template>\\`,\n  styles: [':host{ display: inline-block; position: relative; }'],\n  changeDetection: ChangeDetectionStrategy.OnPush\n})\nexport class @{className}Component implements OnInit, AfterViewInit {\n  private static SEED = 0;\n\n  @Input() public height: string | number = 0;\n  @Input() public viewBox = '';\n  @ViewChild('dynSvg', { read: ViewContainerRef }) public viewContainerRef;\n  @Input() public width: string | number = 0;\n\n  @Input() public set context(ctx) {\n    this._context = ctx;\n    if (this._iconComponent) {\n      this._iconComponent.instance.context = ctx;\n      this._ref.markForCheck();\n    }\n  }\n\n  @Input() public set icon(icon: string) {\n    this._createIcon(icon);\n  }\n\n  public get iconFile(): SVG2TSFile {\n    return this._icon;\n  }\n\n  private _context: any;\n  private _icon: SVG2TSFile;\n  private _iconComponent;\n  private _isStaticIcon = false;\n\n  constructor(\n    private _ref: ChangeDetectorRef,\n    private _componentFactoryResolver: ComponentFactoryResolver,\n    private _elementRef: ElementRef\n  ) {}\n\n  public getViewBox() {\n    return this.viewBox !== ''\n      ? this.viewBox\n      : this._icon.viewBox\n        ? [\n            this._icon.viewBox.minx,\n            this._icon.viewBox.miny,\n            this._icon.viewBox.width,\n            this._icon.viewBox.height\n          ].join(' ')\n        : [0, 0, this._icon.width, this._icon.height].join(' ');\n  }\n\n  public ngAfterViewInit() {\n    if (this._isStaticIcon) {\n      this._createStaticIcon();\n    }\n  }\n\n  public ngOnInit() {\n    if (this._context) {\n      this.context = this._context;\n    }\n  }\n\n  private _createDynamicIcon(icon: string) {\n    const clazz = componentsMap[icon];\n    const factory = this._componentFactoryResolver.resolveComponentFactory<any>(\n      clazz\n    );\n    this._iconComponent = this.viewContainerRef.createComponent(factory);\n  }\n\n  private _createIcon(icon: string) {\n      this._icon = assetsMap[icon];\n      if (!this._icon) {\n        return;\n      }\n      if (this._icon && !this._icon['contextDefaults']) {\n        this._isStaticIcon = true;\n        this.width = this._icon.width;\n        this.height = this._icon.height;\n      } else {\n        this._createDynamicIcon(icon);\n      }\n  }\n\n  private _createStaticIcon() {\n    let svg = (this._icon.css\n      ? \\`<style>\\${this._icon.css.replace(\n        /.((?!})[\\\\S]+?){{uuid}}/g,\n        ''\n      )}</style>\\`\n      : '') + \\`<svg><g>\\${this._icon.svg}</g></svg>\\`;\n\n    svg = this._resolveBasePath(this._replaceIds(svg, OneSvgCoreComponent.SEED++));\n\n    const inline = document.createElement('div');\n    inline.innerHTML = svg;\n\n    this._elementRef.nativeElement.querySelector('svg').appendChild(inline.firstChild);\n  }\n\n  private _replaceIds(source: string, seed: number) {\n    const foundIds = source.match(/id=\"(.*?)\"/g);\n    if (!foundIds) {\n      return source;\n    }\n    const seedPostFix = '-' + seed;\n    const ids: Array<string> = foundIds.map(m => {\n        const a = m.match(/id=\"(.*?)\"/);\n        if (a) {\n          return a[1];\n        }\n        return '';\n      });\n    const prefixed = \\`svg2ts-\\`;\n    // content\n    let result = ids.reduce((acc, id) => {\n      acc = acc\n        // prefix document id's\n        .replace(new RegExp('[\"\\\\']' + id + '[\"\\\\']', 'g'), \\`\"\\${prefixed}\\${id}\\${seedPostFix}\"\\`)\n        // replace document id refs\n        .replace(new RegExp('[\"\\\\']#' + id + '[\"\\\\']', 'g'), \\`\"#\\${prefixed}\\${id}\\${seedPostFix}\"\\`)\n        // replace document id refs in url's\n        .replace(new RegExp('url\\\\\\\\(#' + id + '\\\\\\\\)', 'g'), \\`url(#\\${prefixed}\\${id}\\${seedPostFix})\\`);\n\n      return acc;\n    }, source);\n\n    // styles\n    const styles = result.match(/(<style(.+?)?>)([\\\\s\\\\S]+?)<\\\\/style>/g);\n    if (styles) {\n      result = styles.reduce((acc, styleDef) => {\n        const styleDefSeedIds = ids.reduce((styleDefSeedAcc, id) => {\n          styleDefSeedAcc = styleDefSeedAcc.replace(new RegExp('#' + id + '', 'g'), \\`#\\${prefixed}\\${id}\\${seedPostFix}\\`);\n          return styleDefSeedAcc;\n        }, styleDef);\n\n        return acc.replace(styleDef, styleDefSeedIds);\n      }, result);\n    }\n\n    return result;\n  }\n\n  private _resolveBasePath(svg: string) {\n    const baseUrl = window.location.href.replace(window.location.hash, '');\n\n    return svg\n      .replace(/xlink:href=[\"']#(.*?)[\"']/g, \\`xlink: href = \"\\${baseUrl}#$1\"\\`)\n      .replace(/url\\\\([']?#(.*?)[']?\\\\)/g, \\`url(\\${ baseUrl }#$1)\\`);\n  }\n\n}\n", {
    moduleName: '',
    className: '',
    selector: '',
    components: [],
    assets: [],
    pascalCase: function (str) { return ''; }
});
